@@ -1,5 +1,5 @@
 /*
- * $Id: XfaForm.java 3536 2008-07-07 23:23:10Z xlv $
+ * $Id: XfaForm.java 3735 2009-02-26 01:44:03Z xlv $
  *
  * Copyright 2006 Paulo Soares
  *
@@ -123,9 +123,9 @@ public class XfaForm {
         xfaPresent = true;
         ByteArrayOutputStream bout = new ByteArrayOutputStream();
         if (xfa.isArray()) {
-            ArrayList ar = ((PdfArray)xfa).getArrayList();
+            PdfArray ar = (PdfArray)xfa;
             for (int k = 1; k < ar.size(); k += 2) {
-                PdfObject ob = PdfReader.getPdfObject((PdfObject)ar.get(k));
+                PdfObject ob = ar.getDirectObject(k);
                 if (ob instanceof PRStream) {
                     byte[] b = PdfReader.getStreamBytes((PRStream)ob);
                     bout.write(b);
@@ -141,6 +141,14 @@ public class XfaForm {
         fact.setNamespaceAware(true);
         DocumentBuilder db = fact.newDocumentBuilder();
         domDocument = db.parse(new ByteArrayInputStream(bout.toByteArray()));   
+        extractNodes();
+    }
+    
+    /**
+     * Extracts the nodes from the domDocument.
+     * @since	2.1.5
+     */
+    private void extractNodes() {
         Node n = domDocument.getFirstChild();
         while (n.getChildNodes().getLength() == 0) {
         	n = n.getNextSibling();
@@ -176,11 +184,11 @@ public class XfaForm {
         }
         PdfObject xfa = getXfaObject(reader);
         if (xfa.isArray()) {
-        	ArrayList ar = ((PdfArray)xfa).getArrayList();
+            PdfArray ar = (PdfArray)xfa;
             int t = -1;
             int d = -1;
             for (int k = 0; k < ar.size(); k += 2) {
-                PdfString s = (PdfString)ar.get(k);
+                PdfString s = ar.getAsString(k);
                 if ("template".equals(s.toString())) {
                 	t = k + 1;
                 }
@@ -189,8 +197,8 @@ public class XfaForm {
                 }
             }
             if (t > -1 && d > -1) {
-                reader.killXref((PdfIndirectReference)ar.get(t));
-                reader.killXref((PdfIndirectReference)ar.get(d));
+                reader.killXref(ar.getAsIndirectObject(t));
+                reader.killXref(ar.getAsIndirectObject(d));
                 PdfStream tStream = new PdfStream(serializeDoc(form.templateNode));
                 tStream.flateCompress(writer.getCompressionLevel());
                 ar.set(t, writer.addToBody(tStream).getIndirectReference());
@@ -355,6 +363,7 @@ public class XfaForm {
      */
     public void setDomDocument(org.w3c.dom.Document domDocument) {
         this.domDocument = domDocument;
+        extractNodes();
     }
 
     /**
